@@ -41,8 +41,8 @@ class Cell:
             cell = DurationCell(row_num, col_num, timedelta(days=data["value"]))
         elif cell_type == TSTArchives.formulaErrorCellType:
             cell = ErrorCell(row_num, col_num, None)
-        elif cell_type == TSTArchives.currencyCellValueType:
-            cell = FormulaCell(row_num, col_num, data["value"])
+        elif cell_type == TSTArchives.automaticCellType:
+            cell = BulletedTextCell(row_num, col_num, data["bullets"])
         else:
             raise UnsupportedError(  # pragma: no cover
                 f"Unsupport cell type {cell_type} @:({row_num},{col_num})"
@@ -56,10 +56,11 @@ class Cell:
             cell.size = merge_cells[row_col]["size"]
 
         debug(
-            "%s@[%d,%d]: value=%s",
+            "%s@[%d,%d]: type=%d, value=%s",
             model.table_name(table_id),
             row_num,
             col_num,
+            cell_type,
             str(cell.value),
         )
         return cell
@@ -70,6 +71,7 @@ class Cell:
         self.col = col_num
         self.size = (1, 1)
         self.is_merged = False
+        self.is_bulleted = False
 
     @property
     def formula(self):
@@ -109,6 +111,10 @@ class Cell:
 
         return self._formula
 
+    @property
+    def bullets(self) -> str:
+        return None
+
 
 class NumberCell(Cell):
     def __init__(self, row_num: int, col_num: int, value):
@@ -130,6 +136,22 @@ class TextCell(Cell):
         return self._value
 
 
+class BulletedTextCell(Cell):
+    def __init__(self, row_num: int, col_num: int, value):
+        self._type = TSTArchives.automaticCellType
+        super().__init__(row_num, col_num, value["text"])
+        self._bullets = value["bullets"]
+        self.is_bulleted = True
+
+    @property
+    def value(self) -> str:
+        return self._value
+
+    @property
+    def bullets(self) -> str:
+        return self._bullets
+
+
 class EmptyCell(Cell):
     def __init__(self, row_num: int, col_num: int, value):
         self._type = None
@@ -170,14 +192,14 @@ class DurationCell(Cell):
         return self._value
 
 
-class FormulaCell(Cell):
-    def __init__(self, row_num: int, col_num: int, value):
-        self._type = TSTArchives.formulaCellType
-        super().__init__(row_num, col_num, value)
+# class FormulaCell(Cell):
+#     def __init__(self, row_num: int, col_num: int, value):
+#         self._type = TSTArchives.formulaCellType
+#         super().__init__(row_num, col_num, value)
 
-    @property
-    def value(self):
-        return None
+#     @property
+#     def value(self):
+#         return None
 
 
 class ErrorCell(Cell):
